pub enum APIResponse {
NewBetaUpdate(String),
NewStableUpdate(String),
NewUpdateHotfix(String),
NoUpdate,
UnknownVersion,
}Expand description
This enum controls the possible responses from the server when checking for an update.
Variants
NewBetaUpdate(String)
This means a beta update was found.
NewStableUpdate(String)
This means a major stable update was found.
NewUpdateHotfix(String)
This means a minor stable update was found.
NoUpdate
This means no update was found.
UnknownVersion
This means don’t know if there was an update or not, because the version we got was invalid.