pub enum DataSource {
PackFile,
GameFiles,
ParentFiles,
AssKitFiles,
ExternalFile,
}Expand description
This enum represents the source of the data in the view.
Variants
PackFile
This means the data is from somewhere in our PackFile.
GameFiles
This means the data is from one of the game files.
ParentFiles
This means the data comes from a parent PackFile.
AssKitFiles
This means the data comes from the AssKit files.
ExternalFile
This means the data comes from an external file.