pub enum NewFile {
AnimPack(String),
DB(String, String, i32),
Loc(String),
PortraitSettings(String, u32, Vec<(String, String)>),
Text(String, TextFormat),
VMD(String),
WSModel(String),
}Expand description
This enum contains the data needed to create a new PackedFile.
Variants
AnimPack(String)
Name of the file.
DB(String, String, i32)
Name of the file, Name of the Table, Version of the Table.
Loc(String)
Name of the Table.
PortraitSettings(String, u32, Vec<(String, String)>)
Name of the file, version of the file, and a list of entries that must be cloned from existing values in vanilla files (from, to).
Text(String, TextFormat)
Name of the file and its format.
VMD(String)
Name of the file.
WSModel(String)
Name of the file.