ContainerInfo

Struct ContainerInfo 

pub struct ContainerInfo { /* private fields */ }
This struct is a reduced version of the PackFile one, used to pass just the needed data to an UI.

Don’t create this one manually. Get it From the PackFile one, and use it as you need it.

Implementations

Source

impl ContainerInfo

pub fn file_name(&self) -> &String

The name of the PackFile’s file, if exists. If not, then this should be empty.

pub fn file_path(&self) -> &String

The path of the PackFile on disk, if exists. If not, then this should be empty.

pub fn pfh_version(&self) -> &PFHVersion

The version of the PackFile.

pub fn pfh_file_type(&self) -> &PFHFileType

The type of the PackFile.

pub fn bitmask(&self) -> &PFHFlags

The bitmasks applied to the PackFile.

pub fn compress(&self) -> &CompressionFormat

If the container needs to be compress on save. None for no compression.

pub fn timestamp(&self) -> &u64

The timestamp of the last time the PackFile was saved.