pub struct DependenciesInfo {
pub asskit_tables: Vec<RFileInfo>,
pub vanilla_packed_files: Vec<RFileInfo>,
pub parent_packed_files: Vec<RFileInfo>,
}Expand description
This struct contains the minimal data needed (mainly paths), to know what we have loaded in out dependencies.
NOTE: As this is intended to be a “Just use it and discard it” struct, we allow public members to make operations where we can move out of here faster.
Fields
asskit_tables: Vec<RFileInfo>Full PackedFile-like paths of each asskit-only table.
vanilla_packed_files: Vec<RFileInfo>Full list of vanilla PackedFile paths.
parent_packed_files: Vec<RFileInfo>Full list of parent PackedFile paths.
Implementations
Sourceimpl DependenciesInfo
impl DependenciesInfo
Sourcepub fn asskit_tables(&self) -> &Vec<RFileInfo>
pub fn asskit_tables(&self) -> &Vec<RFileInfo>
Full PackedFile-like paths of each asskit-only table.
Sourcepub fn vanilla_packed_files(&self) -> &Vec<RFileInfo>
pub fn vanilla_packed_files(&self) -> &Vec<RFileInfo>
Full list of vanilla PackedFile paths.
Sourcepub fn parent_packed_files(&self) -> &Vec<RFileInfo>
pub fn parent_packed_files(&self) -> &Vec<RFileInfo>
Full list of parent PackedFile paths.
Sourceimpl DependenciesInfo
impl DependenciesInfo
pub fn new( dependencies: &Dependencies, table_name_logic: &VanillaDBTableNameLogic, ) -> Self