pub enum Response {
Show 84 variants
Success,
Error(String),
SessionConnected(u64),
SettingsChanged(SettingsSnapshot),
BmdRFileInfo(Box<Bmd>, RFileInfo),
AnimFragmentBattleRFileInfo(AnimFragmentBattle, RFileInfo),
AnimPackRFileInfo(Vec<RFileInfo>, RFileInfo),
AnimsTableRFileInfo(AnimsTable, RFileInfo),
APIResponse(APIResponse),
APIResponseGit(GitResponse),
AtlasRFileInfo(Atlas, RFileInfo),
AudioRFileInfo(Audio, RFileInfo),
Bool(bool),
CompressionFormat(CompressionFormat),
CompressionFormatDependenciesInfo(CompressionFormat, Option<DependenciesInfo>),
ContainerInfo(ContainerInfo),
ContainerInfoVecRFileInfo((ContainerInfo, Vec<RFileInfo>)),
StringContainerInfo(String, ContainerInfo),
DataSourceStringUsizeUsize(DataSource, String, usize, usize),
DBRFileInfo(DB, RFileInfo),
Definition(Definition),
DependenciesInfo(DependenciesInfo),
Diagnostics(Diagnostics),
ESFRFileInfo(ESF, RFileInfo),
F32(f32),
GlobalSearchVecRFileInfo(Box<GlobalSearch>, Vec<RFileInfo>),
GroupFormationsRFileInfo(GroupFormations, RFileInfo),
HashMapDataSourceHashMapStringRFile(HashMap<DataSource, HashMap<String, RFile>>),
HashMapDataSourceHashSetContainerPath(HashMap<DataSource, HashSet<ContainerPath>>),
HashMapI32TableReferences(HashMap<i32, TableReferences>),
HashMapStringHashMapStringVecString(HashMap<String, HashMap<String, Vec<String>>>),
HashSetString(HashSet<String>),
HashSetStringHashSetString(HashSet<String>, HashSet<String>),
I32(i32),
I32I32(i32, i32),
I32I32VecStringVecString(i32, i32, Vec<String>, Vec<String>),
ImageRFileInfo(Image, RFileInfo),
LocRFileInfo(Loc, RFileInfo),
MatchedCombatRFileInfo(MatchedCombat, RFileInfo),
MergeConflicts(Vec<MergeConflict>),
Note(Note),
OperationalMode(OperationalMode),
OptimizerOptions(OptimizerOptions),
OptionContainerPath(Option<ContainerPath>),
OptionRFileInfo(Option<RFileInfo>),
OptionStringStringVecString(Option<(String, String, Vec<String>)>),
PackSettings(PackSettings),
PackTranslation(PackTranslation),
PathBuf(PathBuf),
PortraitSettingsRFileInfo(PortraitSettings, RFileInfo),
RFileDecoded(RFileDecoded),
RigidModelRFileInfo(RigidModel, RFileInfo),
Schema(Schema),
String(String),
StringVecContainerPath(String, Vec<ContainerPath>),
StringVecPathBuf(String, Vec<PathBuf>),
Text(Text),
TextRFileInfo(Text, RFileInfo),
UICRFileInfo(UIC, RFileInfo),
UnitVariantRFileInfo(UnitVariant, RFileInfo),
Unknown,
VecBoolString(Vec<(bool, String)>),
VecContainerPath(Vec<ContainerPath>),
VecContainerPathContainerPath(Vec<(ContainerPath, ContainerPath)>),
VecContainerPathOptionString(Vec<ContainerPath>, Option<String>),
VecContainerPathVecContainerPath(Vec<ContainerPath>, Vec<ContainerPath>),
VecContainerPathBTreeMapStringVecContainerPath(Vec<ContainerPath>, BTreeMap<String, Vec<ContainerPath>>),
VecContainerPathVecContainerPathString(Vec<ContainerPath>, Vec<ContainerPath>, String),
VecContainerPathVecRFileInfo(Vec<ContainerPath>, Vec<RFileInfo>),
VecContainerPathVecString(Vec<ContainerPath>, Vec<String>),
VecDataSourceStringStringStringUsizeUsize(Vec<(DataSource, String, String, String, usize, usize)>),
VecDefinition(Vec<Definition>),
VecField(Vec<Field>),
VecNote(Vec<Note>),
VecRFile(Vec<RFile>),
VecRFileInfo(Vec<RFileInfo>),
VecString(Vec<String>),
VecStringTuples(Vec<(String, String)>),
VecStringContainerInfo(Vec<(String, ContainerInfo)>),
VecU8(Vec<u8>),
VideoInfoRFileInfo(VideoInfo, RFileInfo),
VMDRFileInfo(Text, RFileInfo),
WSModelRFileInfo(Text, RFileInfo),
SettingsAll(SettingsSnapshot),
}Expand description
This enum defines the responses (messages) you can send to the UI thread as result of a command.
Each response is named after the types of the items it carries, making them self-documenting.
For example, VecString returns a Vec<String>, and DBRFileInfo returns a (DB, RFileInfo) tuple.
Variants
Success
Generic response for situations of success where no data needs to be returned.
Error(String)
Generic response for situations that returned an error, containing the error message.
SessionConnected(u64)
Response sent by the server immediately after a WebSocket connection is established. Contains the session ID that the client is connected to.
SettingsChanged(SettingsSnapshot)
Unsolicited push sent to every connected client whenever any session changes the shared settings store, so other open UI instances can refresh their local settings cache.
BmdRFileInfo(Box<Bmd>, RFileInfo)
AnimFragmentBattleRFileInfo(AnimFragmentBattle, RFileInfo)
AnimPackRFileInfo(Vec<RFileInfo>, RFileInfo)
AnimsTableRFileInfo(AnimsTable, RFileInfo)
APIResponse(APIResponse)
APIResponseGit(GitResponse)
AtlasRFileInfo(Atlas, RFileInfo)
AudioRFileInfo(Audio, RFileInfo)
Bool(bool)
CompressionFormat(CompressionFormat)
CompressionFormatDependenciesInfo(CompressionFormat, Option<DependenciesInfo>)
ContainerInfo(ContainerInfo)
ContainerInfoVecRFileInfo((ContainerInfo, Vec<RFileInfo>))
StringContainerInfo(String, ContainerInfo)
DataSourceStringUsizeUsize(DataSource, String, usize, usize)
DBRFileInfo(DB, RFileInfo)
Definition(Definition)
DependenciesInfo(DependenciesInfo)
Diagnostics(Diagnostics)
ESFRFileInfo(ESF, RFileInfo)
F32(f32)
GlobalSearchVecRFileInfo(Box<GlobalSearch>, Vec<RFileInfo>)
GroupFormationsRFileInfo(GroupFormations, RFileInfo)
HashMapDataSourceHashMapStringRFile(HashMap<DataSource, HashMap<String, RFile>>)
HashMapDataSourceHashSetContainerPath(HashMap<DataSource, HashSet<ContainerPath>>)
HashMapI32TableReferences(HashMap<i32, TableReferences>)
HashMapStringHashMapStringVecString(HashMap<String, HashMap<String, Vec<String>>>)
HashSetString(HashSet<String>)
HashSetStringHashSetString(HashSet<String>, HashSet<String>)
I32(i32)
I32I32(i32, i32)
I32I32VecStringVecString(i32, i32, Vec<String>, Vec<String>)
ImageRFileInfo(Image, RFileInfo)
LocRFileInfo(Loc, RFileInfo)
MatchedCombatRFileInfo(MatchedCombat, RFileInfo)
MergeConflicts(Vec<MergeConflict>)
Note(Note)
OperationalMode(OperationalMode)
OptimizerOptions(OptimizerOptions)
OptionContainerPath(Option<ContainerPath>)
OptionRFileInfo(Option<RFileInfo>)
OptionStringStringVecString(Option<(String, String, Vec<String>)>)
PackSettings(PackSettings)
PackTranslation(PackTranslation)
PathBuf(PathBuf)
PortraitSettingsRFileInfo(PortraitSettings, RFileInfo)
RFileDecoded(RFileDecoded)
RigidModelRFileInfo(RigidModel, RFileInfo)
Schema(Schema)
String(String)
StringVecContainerPath(String, Vec<ContainerPath>)
StringVecPathBuf(String, Vec<PathBuf>)
Text(Text)
TextRFileInfo(Text, RFileInfo)
UICRFileInfo(UIC, RFileInfo)
UnitVariantRFileInfo(UnitVariant, RFileInfo)
Unknown
VecBoolString(Vec<(bool, String)>)
VecContainerPath(Vec<ContainerPath>)
VecContainerPathContainerPath(Vec<(ContainerPath, ContainerPath)>)
VecContainerPathOptionString(Vec<ContainerPath>, Option<String>)
VecContainerPathVecContainerPath(Vec<ContainerPath>, Vec<ContainerPath>)
VecContainerPathBTreeMapStringVecContainerPath(Vec<ContainerPath>, BTreeMap<String, Vec<ContainerPath>>)
VecContainerPathVecContainerPathString(Vec<ContainerPath>, Vec<ContainerPath>, String)
VecContainerPathVecRFileInfo(Vec<ContainerPath>, Vec<RFileInfo>)
VecContainerPathVecString(Vec<ContainerPath>, Vec<String>)
VecDataSourceStringStringStringUsizeUsize(Vec<(DataSource, String, String, String, usize, usize)>)
VecDefinition(Vec<Definition>)
VecField(Vec<Field>)
VecNote(Vec<Note>)
VecRFile(Vec<RFile>)
VecRFileInfo(Vec<RFileInfo>)
VecString(Vec<String>)
VecStringTuples(Vec<(String, String)>)
VecStringContainerInfo(Vec<(String, ContainerInfo)>)
VecU8(Vec<u8>)
VideoInfoRFileInfo(VideoInfo, RFileInfo)
VMDRFileInfo(Text, RFileInfo)
WSModelRFileInfo(Text, RFileInfo)
SettingsAll(SettingsSnapshot)
All settings in one response (for batch loading).