pub struct ContainerInfo { /* private fields */ }Expand description
This struct is a reduced version of the PackFile one, used to pass just the needed data to an UI.
Don’t create this one manually. Get it From the PackFile one, and use it as you need it.
Implementations
Sourceimpl ContainerInfo
impl ContainerInfo
Sourcepub fn file_name(&self) -> &String
pub fn file_name(&self) -> &String
The name of the PackFile’s file, if exists. If not, then this should be empty.
Sourcepub fn file_path(&self) -> &String
pub fn file_path(&self) -> &String
The path of the PackFile on disk, if exists. If not, then this should be empty.
Sourcepub fn pfh_version(&self) -> &PFHVersion
pub fn pfh_version(&self) -> &PFHVersion
The version of the PackFile.
Sourcepub fn pfh_file_type(&self) -> &PFHFileType
pub fn pfh_file_type(&self) -> &PFHFileType
The type of the PackFile.
Sourcepub fn compress(&self) -> &CompressionFormat
pub fn compress(&self) -> &CompressionFormat
If the container needs to be compress on save. None for no compression.