pub struct RFileInfo { /* private fields */ }Expand description
This struct represents the detailed info about the PackedFile we can provide to whoever request it.
Implementations
Sourceimpl RFileInfo
impl RFileInfo
Sourcepub fn info_from_global_search(
global_search: &GlobalSearch,
packs: &BTreeMap<String, Pack>,
) -> Vec<Self>
pub fn info_from_global_search( global_search: &GlobalSearch, packs: &BTreeMap<String, Pack>, ) -> Vec<Self>
This function returns the PackedFileInfo for all the PackedFiles the current search has searched on.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
Returns the table name for DB files.
For DB files, the path format is db/<table_name>/<file_name>, so this extracts
the second path component. Returns None if the file is not a DB file or if
the path doesn’t have the expected structure.